@@ -90,12 +90,15 @@ class DataViewer(QtWidgets.QMainWindow):
         self.diffraction_space_widget.normRadioChanged()
 
         if len(argv) > 1:
+            from PyQt5.QtWidgets import QApplication
+            QApplication.processEvents()
             path = os.path.abspath(argv[1])
             try:
                 self.settings.data_filename.val = path
                 self.load_file()
-            except Exception:
-                print(f"Tried to set file to {path} but something went wrong...")
+            except Exception as err:
+                print(f"Tried to set file to {path} but something went wrong, got error:")
+                print(err)
 
 
     ###############################################
@@ -320,9 +323,9 @@ class DataViewer(QtWidgets.QMainWindow):
             if is_py4DSTEM_file(fname):
                 self.datacube = datacube_selector(fname)
             else:
-                self.datacube,_ = read(fname, mem="MEMMAP")
+                self.datacube = read(fname, mem="MEMMAP")
         elif self.control_widget.widget_LoadPreprocessSave.widget.loadRadioGatan.isChecked():
-            self.datacube,_ = read(fname, ft='gatan_bin')
+            self.datacube = read(fname, ft='gatan_bin')
 
         # Update scan shape information
         self.settings.R_Nx.update_value(self.datacube.R_Nx)
