@@ -1,17 +1,17 @@
-# Reader for py4DSTEM v0.5 files
+# Reader for py4DSTEM v0.6 files
 
 import h5py
 import numpy as np
 from os.path import splitext
 from .read_utils import is_py4DSTEM_file, get_py4DSTEM_topgroups, get_py4DSTEM_version, version_is_geq
-from .read_utils_v0_5 import get_py4DSTEM_dataobject_info
+from .read_utils_v0_6 import get_py4DSTEM_dataobject_info
 from ...datastructure import DataCube, CountedDataCube, DiffractionSlice, RealSlice
 from ...datastructure import PointList, PointListArray
 from ....process.utils import tqdmnd
 
-def read_v0_5(fp, **kwargs):
+def read_v0_6(fp, **kwargs):
     """
-    File reader for files written by py4DSTEM v0.5.  Precise behavior is detemined by which
+    File reader for files written by py4DSTEM v0.6.  Precise behavior is detemined by which
     arguments are passed -- see below.
 
     ***NOTE: this function has not yet been tested on all legacy py4DSTEM formats. Please report
@@ -72,7 +72,7 @@ def read_v0_5(fp, **kwargs):
             return None,None
 
     version = get_py4DSTEM_version(fp, tg)
-    assert(version == (0,5,0)), "File must be v0.5.0."
+    assert(version == (0,6,0)), "File must be v0.6.0."
     _data_id = 'data_id' in kwargs.keys()  # Flag indicating if data was requested
 
     # Validate inputs
@@ -113,6 +113,10 @@ def print_py4DSTEM_file(fp,tg):
     """ Accepts a fp to a valid py4DSTEM file and prints to screen the file contents.
     """
     info = get_py4DSTEM_dataobject_info(fp,tg)
+
+    version = get_py4DSTEM_version(filepath, tg)
+    print(f"py4DSTEM file version {version[0]}.{version[1]}.{version[2]}")
+
     print("{:10}{:18}{:24}{:54}".format('Index', 'Type', 'Shape', 'Name'))
     print("{:10}{:18}{:24}{:54}".format('-----', '----', '-----', '----'))
     for el in info:
@@ -148,7 +152,15 @@ def get_data_from_int(fp,tg,data_id,mem='RAM',binfactor=1,bindtype=None):
         N = data_id-Ns[i]
         name = sorted(grp.keys())[N]
 
-        grp_data = f[grp.name+'/'+name]
+        group_name = grp.name+'/'+name
+
+        if mem == "RAM":
+            grp_data = f[group_name]
+            data = get_data_from_grp(grp_data,mem=mem,binfactor=binfactor,bindtype=bindtype)
+
+    if mem == "MEMMAP":
+        f = h5py.File(filepath,'r')
+        grp_data = f[group_name]
         data = get_data_from_grp(grp_data,mem=mem,binfactor=binfactor,bindtype=bindtype)
 
     return data
@@ -181,7 +193,17 @@ def get_data_from_str(fp,tg,data_id,mem='RAM',binfactor=1,bindtype=None):
         i_grp = np.nonzero(ind<Ns)[0][0]
         grp = grps[i_grp]
 
-        grp_data = f[grp.name+'/'+data_id]
+        group_name = grp.name+'/'+data_id
+
+        if mem == "RAM":
+            grp_data = f[group_name]
+            data = get_data_from_grp(grp_data,mem=mem,binfactor=binfactor,bindtype=bindtype)
+
+    # if using MEMMAP, file cannot be accessed from the context manager
+    # or else it will be closed before the data is accessed
+    if mem == "MEMMAP":
+        f = h5py.File(filepath,'r')
+        grp_data = f[group_name]
         data = get_data_from_grp(grp_data,mem=mem,binfactor=binfactor,bindtype=bindtype)
 
     return data
@@ -225,8 +247,13 @@ def get_datacube_from_grp(g,mem='RAM',binfactor=1,bindtype=None):
     """ Accepts an h5py Group corresponding to a single datacube in an open, correctly formatted H5 file,
         and returns a DataCube.
     """
-    # TODO: add memmapping, binning
-    data = np.array(g['datacube'])
+    assert binfactor == 1, "Bin on load is currently unsupported for EMD files."
+
+    if (mem, binfactor) == ("RAM", 1):
+        data = np.array(g['data'])
+    elif (mem, binfactor) == ("MEMMAP", 1):
+        data = g['data']
+    
     name = g.name.split('/')[-1]
     return DataCube(data=data,name=name)
 
@@ -240,7 +267,7 @@ def get_diffractionslice_from_grp(g):
     """ Accepts an h5py Group corresponding to a diffractionslice in an open, correctly formatted H5 file,
         and returns a DiffractionSlice.
     """
-    data = np.array(g['diffractionslice'])
+    data = np.array(g['data'])
     name = g.name.split('/')[-1]
     Q_Nx,Q_Ny = data.shape[:2]
     if len(data.shape)==2:
@@ -257,7 +284,7 @@ def get_realslice_from_grp(g):
     """ Accepts an h5py Group corresponding to a realslice in an open, correctly formatted H5 file,
         and returns a RealSlice.
     """
-    data = np.array(g['realslice'])
+    data = np.array(g['data'])
     name = g.name.split('/')[-1]
     R_Nx,R_Ny = data.shape[:2]
     if len(data.shape)==2:
@@ -277,17 +304,17 @@ def get_pointlist_from_grp(g):
     name = g.name.split('/')[-1]
     coordinates = []
     coord_names = list(g.keys())
-    length = len(g[coord_names[0]+'/pointlist'])
+    length = len(g[coord_names[0]+'/data'])
     if length==0:
         for coord in coord_names:
             coordinates.append((coord,None))
     else:
         for coord in coord_names:
-            dtype = type(g[coord+'/pointlist'][0])
+            dtype = type(g[coord+'/data'][0])
             coordinates.append((coord, dtype))
     data = np.zeros(length,dtype=coordinates)
     for coord in coord_names:
-        data[coord] = np.array(g[coord+'/pointlist'])
+        data[coord] = np.array(g[coord+'/data'])
     return PointList(data=data,coordinates=coordinates,name=name)
 
 def get_pointlistarray_from_grp(g):
@@ -300,31 +327,19 @@ def get_pointlistarray_from_grp(g):
     shape = (np.max(ar[:,0])+1,np.max(ar[:,1])+1)
     coord_names = list(g['0_0'])
     N = len(coord_names)
-    coord_types = [type(np.array(g['0_0/'+coord_names[i]+'/pointlistarray'])[0]) for i in range(N)]
+    coord_types = [type(np.array(g['0_0/'+coord_names[i]+'/data'])[0]) for i in range(N)]
     coordinates = [(coord_names[i],coord_types[i]) for i in range(N)]
     pla = PointListArray(coordinates=coordinates,shape=shape,name=name)
     for (i,j) in tqdmnd(range(shape[0]),range(shape[1]),desc="Reading PointListArray",unit="PointList"):
         g_pl = g[str(i)+'_'+str(j)]
-        L = len(np.array(g_pl[coordinates[0][0]+'/pointlistarray']))
+        L = len(np.array(g_pl[coordinates[0][0]+'/data']))
         data = np.zeros(L,dtype=coordinates)
         for i in range(N):
             coord = coordinates[i][0]
-            data[coord] = np.array(g_pl[coord+'/pointlistarray'])
+            data[coord] = np.array(g_pl[coord+'/data'])
         pla.get_pointlist(i,j).add_dataarray(data)
     return pla
 
 
-########### Metadata and log ############
-
-def get_metadata(fp,tg):
-    """ Accepts a fp to a valid py4DSTEM file, and return a dictionary with its metadata.
-    """
-    return #TODO
-
-def write_log(fp,tg):
-    """ Accepts a fp to a valid py4DSTEM file, then prints its processing log to splitext(fp)[0]+'.log'.
-    """
-    return #TODO
-
 
 
