@@ -49,6 +49,8 @@ where b = a*e is the semiminor axis length.
 import numpy as np
 from scipy.optimize import leastsq, least_squares
 from scipy.ndimage.filters import gaussian_filter
+from scipy.signal import savgol_filter
+from scipy.interpolate import interp1d
 from ..utils import get_CoM
 from ...io import PointListArray
 
@@ -332,7 +334,7 @@ def cartesianDataAr_to_polarEllipticalDataAr(
     params,
     dr=1,
     dtheta=np.radians(2),
-    r_range=512,
+    r_range=None,
     mask=None,
     maskThresh=0.99,
 ):
@@ -386,15 +388,34 @@ def cartesianDataAr_to_polarEllipticalDataAr(
         cartesianData.shape == mask.shape
     ), "Mask and cartesian data array shapes must match."
     assert len(params) == 5, "params must have length 5"
-    try:
-        r_min, r_max = r_range[0], r_range[1]
-    except TypeError:
-        r_min, r_max = 0, r_range
-    Nx, Ny = cartesianData.shape
 
     # Get params
     qx0, qy0, A, B, phi = params
 
+    # Define r_range: 
+    if r_range is None: 
+        #find corners of image
+        corners = np.array([
+                            [0,0],
+                            [0,cartesianData.shape[0]],
+                            [0,cartesianData.shape[1]],
+                            [cartesianData.shape[0], cartesianData.shape[1]] 
+                            ])
+        #find maximum corner distance
+        r_min, r_max =0, np.ceil(
+                            np.max(
+                                np.sqrt(
+                                    np.sum((corners -np.broadcast_to(np.array((qx0,qy0)), corners.shape))**2, axis = 1)
+                                       )
+                                   )
+                                ).astype(int)
+    else:
+        try:
+            r_min, r_max = r_range[0], r_range[1]
+        except TypeError:
+            r_min, r_max = 0, r_range
+
+    Nx, Ny = cartesianData.shape
     # Define the r/theta coords
     r_bins = np.arange(r_min + dr / 2.0, r_max + dr / 2.0, dr)  # values are bin centers
     t_bins = np.arange(-np.pi + dtheta / 2.0, np.pi + dtheta / 2.0, dtheta)
@@ -641,4 +662,117 @@ def compare_double_sided_gaussian(data, p, power=1, mask=None):
 
     return
 
+## Create look up table for background subtraction
+def get_1Dbackground(data, qx0, qy0 ,e, phi, 
+                    maskUpdateIter=3, 
+                    min_relative_threshold = 4,
+                    smoothing = False, 
+                    smoothingWindowSize = 3, 
+                    smoothingPolyOrder = 4, 
+                    smoothing_log = True, 
+                    min_background_value=1E-3, 
+                    return_polararr=False):
+    """
+    Gets the median polar background for a diffraction pattern
+
+    Accepts: 
+    data                    (ndarray) the data for which to find the polar eliptical background, usually a diffraction pattern
+    qx0,qy0                 (floats) the ellipse center; if the braggpeaks have been centered,
+                            these should be zero
+    e                       (float) the length ratio of semiminor/semimajor axes
+    phi                     (float) tilt of the major axis with respect  to (qx, qy) axis, in radians 
+    maskUpdate_iter         (integer)
+    min_relative_threshold  (float)
+    smoothing               (bool) if true savgol filter smoothing is applied
+    smoothingWindowSize     (integer) size of the smoothing window, must be odd number
+    smoothingPolyOrder      (number) order of the polynomial smoothing to be applied
+    smoothing_log           (bool) if true log smoothing is performed
+    min_background_value    (float) if log smoothing is true, a zero value will be replaced with a small nonzero float
+    return_polar_arr        (bool) if True the polar transform with the masked high intensity peaks will be returned 
+
+    Returns: 
+    background1D (ndarray) 1D polar elliptical background
+    r_bins       (ndarray) the elliptically transformed radius associated with background1D
+    polarData    (ndarray) **optional: returns the masked polar transform from which the 1D background is computed
+    """
+    # assert data is proper form 
+    assert isinstance(smoothing, bool), "Smoothing must be bool"
+    assert smoothingWindowSize%2==1, 'Smoothing window must be odd' 
+    assert isinstance(return_polararr, bool), "return_polararr must be bool"
+   
+    # Compute Polar Transform
+    polarData, rr, tt = cartesianDataAr_to_polarEllipticalDataAr(data,tuple([qx0,qy0, 1, e, phi]))
+   
+    # Crop polar data to maximum distance which contains information from original image
+    if (polarData.mask.sum(axis = (0))==polarData.shape[0]).any():
+            ii = polar.data.shape[1]
+            while(polar.mask[:,ii].all()==True):
+                ii = ii-1
+            maximalDistance = ii
+            polarData = polarData[:,0:maximalDistance]
+            r_bins = rr[0,0:maximalDistance]
+    else:
+            r_bins = rr[0,:]
+
+    # Iteratively mask off high intensity peaks
+    maskPolar = np.copy(polarData.mask)
+    for ii in range(maskUpdateIter+1): 
+        if ii > 0:    
+            maskUpdate = np.logical_or(maskPolar,  
+                                        polarData/background1D > min_relative_threshold)
+            # Prevent entire columns from being masked off 
+            colMaskMin = np.all(maskUpdate, axis = 0)  # Detect columns that are empty
+            maskUpdate[:,colMaskMin] = polarData.mask[:,colMaskMin] # reset empty columns to values of previous iterations
+            polarData.mask  = maskUpdate  # Update Mask
+
+        background1D = np.ma.median(polarData, axis = 0) 
+
+    background1D = np.maximum(background1D, min_background_value)
+
+    if smoothing == True:
+        if smoothing_log==True: 
+            background1D = np.log(background1D)
+
+        background1D = savgol_filter(background1D, 
+                                     smoothingWindowSize, 
+                                     smoothingPolyOrder)
+        if smoothing_log==True: 
+            background1D = np.exp(background1D)
+    if return_polararr ==True: 
+        return(background1D, r_bins, polarData)
+    else: 
+        return(background1D, r_bins)
+
+#Create 2D Background 
+def get_2Dbackground(data, background1D, r_bins, qx0, qy0, phi, e):
+    """
+    Gets 2D polar elliptical background from linear 1D background 
+
+    Accepts:
+    data            (ndarray) the data for which to find the polar eliptical background, usually a diffraction pattern
+    background1D:   (ndarray) a vector representing the radial elliptical background 
+    r_bins:         (ndarray) a vector of the elliptically transformed radius associated with background1D
+    qx0,qy0         (floats) the ellipse center; if the braggpeaks have been centered,
+                              these should be zero
+    e               (float) the length ratio of semiminor/semimajor axes
+    phi             (float) tilt of the major axis with respect  to (qx, qy) axis, in radians 
+
+    Returns: 
+    2D Background   (ndarray) 2D polar elliptical median background image
+    """
+    assert r_bins.shape==background1D.shape, "1D background and r_bins must be same length"
+    # Define centered 2D cartesian coordinate system
+    yc, xc = np.meshgrid(np.arange(0,data.shape[1])-qy0, 
+                         np.arange(0,data.shape[0])-qx0)
+   
+
+    # Calculate the semimajor axis distance for each point in the 2D array
+    r = np.sqrt(((xc*np.cos(phi)+yc*np.sin(phi))**2)+
+                (((xc*np.sin(phi)-yc*np.cos(phi))**2)/(e**2)))
+
+    # Create a 2D eliptical background using linear interpolation  
+    f = interp1d(r_bins, background1D, fill_value = 'extrapolate')
+    background2D = f(r)
+
+    return(background2D)
 
